@@ -20,9 +20,9 @@ def find_one(tag: str, attrs: Optional[Dict[str, Any]] = None, partial: bool = F
     return _
 
 
-def find_many(tag: str, attrs: Optional[Dict[str, Any]] = None) -> Callable[[Soup], Maybe[List[Soup]]]:
+def find_many(tag: str, attrs: Optional[Dict[str, Any]] = None, partial: bool = False) -> Callable[[Soup], Maybe[List[Soup]]]:
     def _(soup: Soup) -> Maybe[List[Soup]]:
-        result = soup.find(tag, attrs, partial=False, mode='all')
+        result = soup.find(tag, attrs, partial=partial, mode='all')
 
         if type(result) is Soup:
             return Some([result])
